Documentation
¶
Overview ¶
Provides Random Lorem Ipsum, and other utilities.
Index ¶
- Variables
- func ClassicParagraph() string
- func ClassicSentence() string
- func ClassicWords(quantity int) string
- func ClassicWordsPerParagraph() int
- func ClassicWordsPerSentence() int
- func Domain() string
- func Email() string
- func FormattedLoremWords(quantity int) string
- func LoremWords(quantity int) string
- func Paragraph() string
- func Sentence() string
- func Title() string
- func URL() string
- func Word() string
- type Lorem
Constants ¶
This section is empty.
Variables ¶
var DATA [1100]string = [1100]string{} /* 1100 elements not displayed */
A lot of Lorem Ipsum Words.
var TLDS = []string{
"com",
"net",
"org",
"fr",
"de",
"uk",
"cn",
"ru",
"br",
"in",
"jp",
"ca",
"us",
"it",
"au",
"es",
"nl",
"se",
"mx",
"ch",
"pl",
"ar",
"be",
"no",
"at",
"dk",
"fi",
"pe",
"io",
"co",
"ai",
"tv",
"me",
"app",
"dev",
"xyz",
"biz",
"pro",
}
Functions ¶
func ClassicParagraph ¶
func ClassicParagraph() string
ClassicParagraph returns the classic Lorem Ipsum paragraph that starts with "Lorem ipsum dolor sit amet, consectetur adipiscing elit..."
func ClassicSentence ¶
func ClassicSentence() string
ClassicSentence returns a sentence from the classic Lorem Ipsum text
func ClassicWords ¶
ClassicWords returns the specified number of words from the classic Lorem Ipsum text
func ClassicWordsPerParagraph ¶ added in v1.3.2
func ClassicWordsPerParagraph() int
ClassicWordsPerSentence returns the word count per praragraph
func ClassicWordsPerSentence ¶ added in v1.3.2
func ClassicWordsPerSentence() int
ClassicWordsPerSentence returns the word count per sentence
func FormattedLoremWords ¶
Get [quantity] words, the first word is capitalized, ends with a dot.
func Paragraph ¶
func Paragraph() string
Get a paragraph, with the first word capitalized, of forty five words that ends with a dot.
Types ¶
type Lorem ¶ added in v1.3.3
Lorem represents generated Lorem Ipsum text with metadata
func ClassicGenerate ¶ added in v1.3.3
ClassicGenerate creates classic Lorem Ipsum text with specified paragraphs and sentences. Each paragraph contains exactly 'sentences' sentences. Each sentence contains 8 words from the classic Lorem Ipsum text.
Example: ClassicGenerate(3, 5) creates 3 paragraphs, each with 5 sentences.
This differs from the CLI behavior where -p and -s are additive.
func Generate ¶ added in v1.3.3
Generate creates Lorem Ipsum text with specified paragraphs and sentences. Each paragraph contains exactly 'sentences' sentences. Each sentence contains 8 random words.
Example: Generate(3, 5) creates 3 paragraphs, each with 5 sentences.
This differs from the CLI behavior where -p and -s are additive.